<!--
SPDX-FileCopyrightText: 2024 Helmholtz-Zentrum Dresden - Rossendorf (HZDR)

SPDX-License-Identifier: CC-BY-SA-4.0
-->

# User Documentation

This is the documentation for the METABOLATOR web app.

<details><summary>Introduction</summary>

A calorimeter captures the heat flow signal of a culture of microorganisms and records the power generated in units of watts as a function of time in units of seconds or minutes.
This time plot can be transformed to the [enthalpy domain](https://doi.org/10.3390%2Fmicroorganisms10071397) to a function of power generated in units of watts as a function of heat flow in units of joules.
This webtool can not only be used to display the raw data captured by the calorimeter and view the raw data in enthalpy domain,
but can also be used to fit the [Monod's growth equation](https://doi.org/10.1146/annurev.mi.03.100149.002103) on the data produced by the calorimeter.

The [Monod's growth equation](https://doi.org/10.1146/annurev.mi.03.100149.002103)
is characterized by the following quanties:

- H0: heat equivalent produced by the initial amount of nutrients if metabolized in a single biochemical pathway by cultured cells
- Hf: heat equivalent of the amount of nutrients that generates half-maximal metabolic thermal power
- ΔH: heat released by a cell during the time Δt between cell divisions (symbolized by arrows)
- ΔA: increment in apparently catalytic surface A due to the formation of a new cell
- H(t): accumulated released heat up to time t in proportion to the amount of biomass
- Θ: “metabolic load” describing the fraction of occupied nutrient-binding sites on A (H0 − H(t) scales with the amount of nutrients at time t)
- P: thermal power of a culture of microorganisms expressed as the product of released heat H, maximal growth rate r0

![Figure 1](images/microorganisms-10-01397-g002.jpg)

The fitting procedure determines the model parameters H0, Hf and r0.

</details>

<details><summary> Fitting procedure</summary>

**Step 1: Uploading and selecting the raw data**

The first step is to choose the file containing the raw data for uploading using the **Browse files** button.

![Figure 2: Uploading (1)](images/Data_Upload.png)

The data can be uploaded by clicking **Start Upload** button.
Only spreadsheet files (e.g. xls, xlsx, ods) can be uploaded.
The file contents are parsed for measurements automatically and the measurements are displayed in the selection window **Select the samples**.

![Figure 3: Uploading (2)](images/Data_Upload_1_.png)


**Step 2: Visualizing the data and fitting the model**

**1. Visualising time plots**

The raw data can be selected and displayed in the time domain using the `Time Plot` button in the **Plot and Analyze** section.

![Figure 4: Time Plot](images/Time_Plot.png)

**2. Visualising enthalpy plots**

The enthalpy domain can be selected using the `Enthalpy Plot` button in the **Plot and Analyze** section.

![Figure 5: Enthalpy Plot](images/Enthalpy_Plot.png)

The plots can be saved by clicking the `camera` icon, which appears while the mouse pointer hovers over the plot. Other options for selecting certain regions of the plots are also available.

**3. Applying offsetting**

Offsetting (shifting of the origin) can be done to account for errors or noisy data arising due to machine calibration and various other factors.
The two options available are:

- `Time Offset`
- `Power Offset`

for the time and enthalpy domain, respectively.
These offset values can be set by the user in the **Select Ranges** section.
The offsetting is activated by clicking the `Check Offsetting` button in the **Plot and Analyze** section.

**4. Initiate fitting procedure**

The fitting procedure is based on the [Monod's growth equation](https://doi.org/10.1146/annurev.mi.03.100149.002103)
and is described in detail [here](https://doi.org/10.3390/microorganisms10071397).

The fitting range for the heat domain can be selected using the `Heat Range Slider` or by manually entering the lower and upper limit.
The default values of the lower and upper limit are set to 0.34 and 0.87, respectively.
The ideal fitting range should in general contain the maximum peak of heat flow.
This can also can be activated using the `Estimate Heat Range` button, that makes use of a four point method to determine the
ideal lower and upper limit. Finally, the fitting procedure can be initiated by clicking the `Analyze Data/Fit` button,
that results in a fit for the selected range both in the time as well as enthalpy domain.


![Figure 6: Fitting](images/Fit.png)


To analyze a the next Heat Flow Signal, the user can click on the new signal in the selector widget and repeat all the above steps to analyze and visualize.

To download the results of all analyses, the user can click on the `file_name_analysis.xlsx` beside the **Download** text to download the results of the analysis.

![Figure 7: Output File](images/Output_Excel.png)

**5. Initiate new analysis batch:**

To begin a new analysis for a new data file, the user can use the **Browse files** and **Start Upload** buttons to start from scratch.
All previous analysis results are cleared when a new file is uploaded.

</details>
