# SPDX-FileCopyrightText: 2024 Helmholtz-Zentrum Dresden - Rossendorf (HZDR)
#
# SPDX-License-Identifier: Apache-2.0

import plotly.graph_objects as go


def enthalpy(x, y, name):
    fig = go.Figure(go.Scatter(x=x, y=y, mode="lines"))
    fig.update_layout(
        title=f"Enthalpy {name}", xaxis_title="Heat (J)", yaxis_title="Power (µW)"
    )
    return fig


def time(x, y, name):
    fig = go.Figure(go.Scatter(x=x, y=y, mode="lines"))
    fig.update_layout(
        title=f"Time {name}", xaxis_title="Time (s)", yaxis_title="Power (µW)"
    )
    return fig


def offsetted(x, y, name):
    fig = go.Figure(go.Scatter(x=x, y=y, mode="lines"))
    fig.update_layout(
        title=f"Offsetted {name}", xaxis_title="Time (s)", yaxis_title="Power (µW)"
    )
    return fig


def plot_fitting(x, y, title):
    """x = (x, xc, th, x_fit), y = (y, yc, y_data, yf1)"""
    fig = go.Figure()
    fig.data = []
    fig.add_trace(go.Scatter(x=x[0], y=y[0], mode="lines", name="extended"))
    fig.add_trace(
        go.Scatter(x=x[1], y=y[1], mode="lines", name="Selected Range"),
    )
    fig.add_trace(go.Scatter(x=x[2], y=y[2], name="Original"))
    fig.add_trace(
        go.Scatter(x=x[3], y=y[3], mode="lines", name="Fitted"),
    )

    fig.update_xaxes(
        title_text="Heat (J)",
        showgrid=True,
        gridwidth=0.5,
        gridcolor="lightgray",
    )
    fig.update_yaxes(
        title_text="Power (µW)",
        showgrid=True,
        gridwidth=0.5,
        gridcolor="lightgray",
    )
    fig.update_layout(height=800, showlegend=True, hovermode="x unified")
    fig.update_xaxes(tickmode="auto", nticks=10)
    fig.update_traces(hovertemplate="Heat: %{x:.2f}J<br>Power: %{y:.2f}µW")
    fig.update_layout(legend={"traceorder": "reversed"}, showlegend=True)
    fig.update_layout(title=title)

    return fig


def plot_fitting_time(x, y):
    fig_t = go.Figure()
    fig_t.add_trace(go.Scatter(x=x[0], y=y[0], mode="lines", name="Fitted Time"))
    fig_t.add_trace(
        go.Scatter(x=x[1], y=y[1], mode="lines", name="Original time"),
    )

    fig_t.update_layout(xaxis_title="Time (s)", yaxis_title="Power (µW)")
    return fig_t
